@@ -7,8 +7,16 @@ import pandas as pd
 from numpy.testing import assert_array_almost_equal
 import matplotlib.pyplot as plt
 
+try:
+    import plotly.graph_objects as go
+    PLOTLY_FOUND = True
+except ImportError:
+    print('No plotly installed. Skip plot tests')
+    PLOTLY_FOUND = False
+
 from skgstat import Variogram
 from skgstat import estimators
+from skgstat import plotting
 
 
 class TestVariogramInstatiation(unittest.TestCase):
@@ -541,7 +549,7 @@ class TestVariogramQaulityMeasures(unittest.TestCase):
 
         for model, rmse in zip(
                 ['spherical', 'gaussian', 'matern', 'stable'],
-                [3.3705, 3.3707, 3.1548, 3.193]
+                [3.3705, 3.3707, 3.1811, 3.193]
         ):
             V.set_model(model)
             self.assertAlmostEqual(V.rmse, rmse, places=4)
@@ -551,7 +559,7 @@ class TestVariogramQaulityMeasures(unittest.TestCase):
 
         for model, mr in zip(
             ['spherical', 'cubic', 'matern', 'stable'],
-            [2.6803, 2.6803, 2.637, 2.6966]
+            [2.6803, 2.6803, 2.6701, 2.6966]
         ):
             V.set_model(model)
             self.assertAlmostEqual(V.mean_residual, mr, places=4)
@@ -665,7 +673,7 @@ class TestVariogramMethods(unittest.TestCase):
         V = self.V.clone()
         
         # test matern
-        param = [42.3, 16.2,  0.1,  0.]
+        param = [42.3, 15.42, 0.11, 0.]
         V.set_model('matern')
         assert_array_almost_equal(V.parameters, param, decimal=2)
     
@@ -864,6 +872,77 @@ class TestVariogramPlots(unittest.TestCase):
         )
 
 
+class TestVariogramPlotlyPlots(unittest.TestCase):
+    def setUp(self):
+        # set up default values, whenever c and v are not important
+        np.random.seed(42)
+        self.c = np.random.gamma(10, 4, (150, 2))
+        np.random.seed(42)
+        self.v = np.random.normal(10, 4, 150)
+        self.V = Variogram(self.c, self.v)
+
+    def test_plotly_main_plot(self):
+        if PLOTLY_FOUND:
+            # switch to plotly
+            plotting.backend('plotly')
+
+            self.assertTrue(
+                isinstance(self.V.plot(show=False), go.Figure)
+            )
+
+            plotting.backend('matplotlib')
+
+    def test_plotly_scattergram(self):
+        if PLOTLY_FOUND:
+            # switch to plotly
+            plotting.backend('plotly')
+
+            self.assertTrue(
+                isinstance(self.V.scattergram(show=False), go.Figure)
+            )
+
+            plotting.backend('matplotlib')
+
+    def test_plotly_location_trend(self):
+        if PLOTLY_FOUND:
+            # switch to plotly
+            plotting.backend('plotly')
+
+            self.assertTrue(
+                isinstance(self.V.location_trend(show=False), go.Figure)
+            )
+
+            plotting.backend('matplotlib')
+
+    def test_plotly_dd_plot(self):
+        if PLOTLY_FOUND:
+            # switch to plotly
+            plotting.backend('plotly')
+
+            self.assertTrue(
+                isinstance(self.V.distance_difference_plot(show=False), go.Figure)
+            )
+
+            plotting.backend('matplotlib')
+    
+    def test_undefined_backend(self):
+        # force the backend into an undefined state
+        import skgstat
+        skgstat.__backend__ = 'not-a-backend'
+
+        for fname in ('plot', 'scattergram', 'location_trend', 'distance_difference_plot'):
+            with self.assertRaises(ValueError) as e:
+                self.V.plot()
+
+                self.assertEqual(
+                    str(e.exception),
+                    'The plotting backend has an undefined state.'
+                )
+        
+        # make the backend valid again
+        skgstat.__backend__ = 'matplotlib'
+
+
 class TestVariogramPickling(unittest.TestCase):
     def setUp(self):
         # set up default values, whenever c and v are not important
